@@ -1,8 +1,6 @@
 ## Domain Registry Interface, DENIC policies
 ##
-## Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-##           (c) 2010,2011,2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
-##           (c) 2012-2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -12,18 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::DRD::DENIC;
 
-use utf8;
 use strict;
-use warnings;
-
 use base qw/Net::DRI::DRD/;
 
+use Net::DRI::DRD::ICANN;
 use DateTime::Duration;
-use Net::DRI::Util;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -45,7 +45,7 @@ Please also see the SUPPORT file in the distribution.
 
 =head1 SEE ALSO
 
-E<lt>http://www.dotandco.com/services/software/Net-DRI/E<gt>
+E<lt>http://oss.bsdprojects.net/projects/netdri/E<gt>
 
 =head1 AUTHOR
 
@@ -53,9 +53,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2009 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2011,2014 Patrick Mevzek <netdri@dotandco.com>.
-          (c) 2012 Michael Holloway <michael@thedarkwinter.com>.
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,21 +72,46 @@ sub new
  my $class=shift;
  my $self=$class->SUPER::new(@_);
  $self->{info}->{host_as_attr}=1;
+
+ bless($self,$class);
  return $self;
 }
 
 sub periods  { return map { DateTime::Duration->new(years => $_) } (1..10); }
 sub name     { return 'DENIC'; }
-sub tlds     { return ('de','9.4.e164.arpa'); } ## *.9.4.e164.arpa could be queried over IRIS DCHK in the past, do not know about RRI support
-sub object_types { return ('domain','contact'); }
-sub profile_types { return qw/rri/; }
+sub tlds     { return ('de'); }
+sub object_types { return ('domain','contact','ns'); }
+
+sub transport_protocol_compatible
+{
+ my ($self,$to,$po)=@_;
+ my $pn=$po->name();
+ my $pv=$po->version();
+ my $tn=$to->name();
+
+ return 1 if (($pn eq 'RRI') && ($tn eq 'socket_inet'));
+ return;
+}
 
 sub transport_protocol_default
 {
- my ($self,$type)=@_;
-
- return ('Net::DRI::Transport::Socket',{remote_host=>'rri.test.denic.de',remote_port=>51131,defer=>1,close_after=>1,socktype=>'tcp'},'Net::DRI::Protocol::RRI',{version=>'2.0'}) if $type eq 'rri';
- return;
+ my ($drd,$ndr,$type,$ta,$pa)=@_;
+ $type='rri' if (!defined($type) || ref($type));
+ if ($type eq 'rri')
+ {
+  return ('Net::DRI::Transport::Socket','Net::DRI::Protocol::RRI') unless (defined($ta) && defined($pa));
+  my %ta=( defer=>1,
+           close_after=>1,
+           socktype=>'tcp',
+           remote_host=>'rri.test.denic.de',
+           remote_port=>51131,
+           protocol_connection=>'Net::DRI::Protocol::RRI::Connection',
+           protocol_version=>'2.0',
+           (ref($ta) eq 'ARRAY')? %{$ta->[0]} : %$ta,
+         );
+  my @pa=(ref($pa) eq 'ARRAY' && @$pa)? @$pa : ('2.0');
+  return ('Net::DRI::Transport::Socket',[\%ta],'Net::DRI::Protocol::RRI',\@pa);
+ }
 }
 
 ####################################################################################################
@@ -96,10 +119,26 @@ sub transport_protocol_default
 sub verify_name_domain
 {
  my ($self,$ndr,$domain,$op)=@_;
- return $self->_verify_name_rules($domain,$op,{check_name => 1,
-                                               my_tld => 1,
-                                               icann_reserved => 1, ## is that right ??
-                                              });
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ my $r=$self->SUPER::check_name($domain,1);
+ return $r if ($r);
+ return 10 unless $self->is_my_tld($domain);
+ return 11 if Net::DRI::DRD::ICANN::is_reserved_name($domain,$op);
+
+ return 0;
+}
+
+sub domain_operation_needs_is_mine
+{
+ my ($self,$ndr,$domain,$op)=@_;
+ ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
+
+ return unless defined($op);
+
+ return 1 if ($op=~m/^(?:renew|update|delete)$/);
+ return 0 if ($op eq 'transfer');
+ return;
 }
 
 sub contact_update
@@ -123,7 +162,6 @@ sub contact_update
 sub domain_update
 {
  my ($self, $reg, $dom, $changes, $rd) = @_;
- $rd=Net::DRI::Util::create_params('domain_update',$rd);
  my $cs = $reg->get_info('contact', 'domain', $dom);
  my $ns = $reg->get_info('ns', 'domain', $dom);
 
@@ -146,29 +184,5 @@ sub domain_trade
  return $reg->process('domain', 'trade', [$dom, $rd]);
 }
 
-sub domain_transit
-{
- my ($self, $reg, $dom, $rd) = @_;
- return $reg->process('domain', 'transit', [$dom, $rd]);
-}
-
-sub domain_migrate_descr
-{
- my ($self, $reg, $dom, $rd) = @_;
- return $reg->process('domain', 'migrate_descr', [$dom, $rd]);
-}
-
-sub domain_create_authinfo
-{
- my ($self, $reg, $dom, $rd) = @_;
- return $reg->process('domain', 'create_authinfo', [$dom, $rd]);
-}
-
-sub domain_delete_authinfo
-{
- my ($self, $reg, $dom, $rd) = @_;
- return $reg->process('domain', 'delete_authinfo', [$dom, $rd]);
-}
-
 ####################################################################################################
 1;
