@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .ASIA
 ##
-## Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Data::Contact::ASIA;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::Data::Contact/;
+__PACKAGE__->mk_accessors(qw(cedcc cedsp cedcity cedetype cediform cedinum
+	cedothertype cedoiform));
 
-__PACKAGE__->register_attributes(qw(cedcc cedsp cedcity cedetype cediform cedinum cedothertype cedoiform));
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -60,6 +64,10 @@ Stores the CED Identification Form.
 
 Stores the CED Identification Number.
 
+=head2 cedinum()
+
+Stores the CED Identification Number.
+
 =head2 cedothertype()
 
 Stores the CED other legal entity type.
@@ -86,7 +94,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
