@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for BR
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Data::Contact::BR;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::Data::Contact/;
+__PACKAGE__->mk_accessors(qw(orgid type associated_contacts associated_domains responsible proxy));
+
 use Net::DRI::Exception;
 
-__PACKAGE__->register_attributes(qw(orgid type associated_contacts associated_domains responsible proxy));
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -63,7 +66,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -87,7 +90,7 @@ sub validate
 
  if (!$change)
  {
-##  Net::DRI::Exception::usererr_insufficient_parameters('orgid is mandatory') unless $self->orgid();
+  Net::DRI::Exception::usererr_insufficient_parameters('orgid is mandatory') unless $self->orgid();
  }
 
  push @errs,'orgid' if ($self->orgid() && !Net::DRI::Util::xml_is_token($self->orgid(),1,30));
@@ -97,16 +100,5 @@ sub validate
  return 1; ## everything ok.
 }
 
-sub init
-{
- my ($self,$what,$ndr)=@_;
-
- if ($what eq 'create')
- {
-  $self->srid('auto') unless defined($self->srid()); ## we can not choose the ID for pure contacts (but we can for brorg creations it seems)
- }
- return;
-}
-
 ####################################################################################################
 1;
