@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .DE
 ##
-## Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
+## Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,19 +10,22 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Data::Contact::DENIC;
 
 use strict;
-use warnings;
-
 use base qw/Net::DRI::Data::Contact/;
+__PACKAGE__->mk_accessors(qw(type sip remarks));
+
 use Net::DRI::Exception;
 use Net::DRI::Util;
 use Email::Valid;
 
-__PACKAGE__->register_attributes(qw(type sip remarks));
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -69,7 +72,7 @@ Tonnerre Lombard E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+Copyright (c) 2007 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -99,7 +102,6 @@ sub validate ## See DENIC-11
 				3, 32);
 	}
 
-	## TODO: convert that to a test on srid(), testing roid() is useless
 	## \w includes _ in Perl
 	push(@errs,'roid') if ($self->roid() &&
 		$self->roid() !~ m/^\w{1,80}-\w{1,8}$/);
