@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .NO
 ##
-## Copyright (c) 2008-2011,2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>.
 ##                    All rights reserved.
 ##
@@ -12,24 +12,27 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ###############################################################################
 
 package Net::DRI::Data::Contact::NO;
 
-use utf8;
 use strict;
-use warnings;
-use base qw/Net::DRI::Data::Contact/;
 use Email::Valid;
 use Net::DRI::Util;
 use Net::DRI::Exception;
 
-__PACKAGE__->register_attributes(qw(type identity mobilephone organization rolecontact xemail xdisclose facets));
+use base qw/Net::DRI::Data::Contact/;
+
+__PACKAGE__->mk_accessors(
+    qw(type identity mobilephone organization rolecontact xemail xdisclose));
+
+our $VERSION = do { my @r = ( q$Revision: 1.1 $ =~ /\d+/gmx ); sprintf( "%d" . ".%02d" x $#r, @r ); };
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 Net::DRI::Data::Contact::NO - Handle .NO contact data for Net::DRI
@@ -44,22 +47,22 @@ This subclass of Net::DRI::Data::Contact adds accessors and validation for
 The following accessors/mutators can be called in chain, as they all return 
 the object itself.
 
-=head2 type()
+=head2 type() 
 
 Mandatory, must be set for all contacts. Specify what type of contact to 
 register. Value must be one of: 'person', 'organization' or 'role'.
 
 Example: $co->type('organization')
 
-=head2 identity()
+=head2 identity() 
 
 Currently valid for type='organization' only.
-Must then be set to specify the organization number in Brønnøysund,
+Must then be set to specify the organization number in Brnnysund,
 the Norwegian Business Register.
 
 Example: $co->identity({type=>'organizationNumber', value=>'987654321'});
-
-=head2 mobilephone()
+ 
+=head2 mobilephone() 
 
 Optional. Set a mobile phone number for the contact.
 
@@ -101,19 +104,6 @@ policy is used.
 
 Example: $co->xdisclose({mobilePhone=>0});
 
-=head2 facets()
-Facets are some special control attributes that can be used to
-implement a super registrar (admin registrar).
-
-A super registrar can suppress certain checks and perform actions on behalf of a normal registrar.
-
-Facets are key/values pairs.
-Net::DRI will not try to enforce what key/value pairs that are possible,
-but let the registry decide their validity.
-
-Example: $co->facets( { 'skip-manual-review' => 1, 'ignores-exceptions' => 'reg123'} );
-
-
 =head1 SUPPORT
 
 For now, support questions should be sent to:
@@ -132,7 +122,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2011,2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>.
 All rights reserved.
 
@@ -163,13 +153,17 @@ sub validate {
             && $self->email()
             && $self->auth()
             && $self->srid();
-
+        Net::DRI::Exception::usererr_insufficient_parameters(
+            'Invalid contact information: org is not allowed for .NO')
+            if ( $self->org() );
         Net::DRI::Exception::usererr_insufficient_parameters(
             'Invalid contact information: type mandatory')
             unless ( $self->type() );
     }
 
-    push @errs,'srid' if ($self->srid() && ! Net::DRI::Util::xml_is_token($self->srid(),3,16));
+    push @errs, 'roid'
+        if ( $self->roid() && $self->roid() !~ m/^\w{1,80}-\w{1,8}$/mx )
+        ;    ## \w includes _ in Perl
     push @errs, 'name'
         if ( $self->name()
         && grep { !Net::DRI::Util::xml_is_normalizedstring( $_, 1, 255 ) }
@@ -249,11 +243,10 @@ sub validate {
         push @errs, 'identity type'
             if ( $ty
             && $ty
-            !~ m/^(?:organizationNumber|localIdentity|nationalIdentityNumber|anonymousPersonIdentifier)$/mx
+            !~ m/^(?:organizationNumber|localIdentity|nationalIdentityNumber)$/mx
             );
 
-        # let the server handle further validation of what identity syntax
-        # and values are legal
+# let the server handle validation of what identity syntax and values are legal
     }
     $t = $self->mobilephone();
     push @errs, 'mobilephone'
@@ -261,50 +254,51 @@ sub validate {
         && !Net::DRI::Util::xml_is_token( $t, undef, 17 )
         && $t !~ m/^\+[0-9]{1,3}\.[0-9]{1,14}(?:x\d+)?$/mx );
 
-    #
-    foreach my $el ( 'organization', 'rolecontact', 'xemail' ) {
-        if ( $t = $self->$el() ) {    # option, as scalar or array
-            my @em;
-            my $er;
+    $t = $self->organization();
+    push @errs, 'organization'
+        if ( $t && !Net::DRI::Util::xml_is_token( $t, 3, 16 ) );
 
-            if ($change) {
-                if ( ref($t) eq 'HASH' ) {
-                    foreach my $s ( 'add', 'del' ) {
-                        my $e = $t->{$s};
-                        if ( ref($e) eq 'ARRAY' ) {
-                            push @em, @$e if (@$e);
-                        } else {
-                            push @em, $e if ($e);
-                        }
+    $t = $self->rolecontact();
+    push @errs, 'roleContact'
+        if ( $t && !Net::DRI::Util::xml_is_token( $t, 3, 16 ) );
+
+    if ( $t = $self->xemail() )
+    {    # option, multiple emails, as scalar or array
+        my @em;
+        my $er;
+
+        # validate all xemail addresses
+        if ($change) {
+            if ( ref($t) eq 'HASH' ) {
+                foreach my $s ( 'add', 'del' ) {
+                    my $e = $t->{$s};
+                    if ( ref($e) eq 'ARRAY' ) {
+                        push @em, @$e if (@$e);
+                    } else {
+                        push @em, $e if ($e);
                     }
-                } else {
-                    $er .= ":update needs an add/del hash:";
                 }
             } else {
-                if ( ref($t) eq 'ARRAY' ) {
-                    push @em, @$t if (@$t);
-                } else {
-                    push @em, $t if ($t);
-                }
+                $er .= ":update needs an add/rem hash:";
             }
-            foreach my $e (@em) {
-                if ( $el eq 'xemail' ) {
-                    $er .= " $e "
-                        if (
-                        $e
-                        && !(
-                            Net::DRI::Util::xml_is_token( $e, 1, undef )
-                            && Email::Valid->rfc822($e)
-                        )
-                        );
-                } else {
-                    $er .= " $e "
-                        if ( $e
-                        && !Net::DRI::Util::xml_is_token( $e, 3, 16 ) );
-                }
-                push @errs, "$el:$er" if ($er);
+        } else {
+            if ( ref($t) eq 'ARRAY' ) {
+                push @em, @$t if (@$t);
+            } else {
+                push @em, $t if ($t);
             }
         }
+        foreach my $e (@em) {
+            $er .= " $e "
+                if (
+                $e
+                && !(
+                    Net::DRI::Util::xml_is_token( $e, 1, undef )
+                    && Email::Valid->rfc822($e)
+                )
+                );
+        }
+        push @errs, "xemail:$er" if ($er);
     }
 
     ## Check that xdisclose only contains mobilePhone
@@ -324,7 +318,7 @@ sub validate {
 }
 
 sub init {
-    my ( $self, $what, $ndr ) = @_;
+    my ( $self, $what ) = @_;
 
     if ( $what eq 'create' ) {
         my $a = $self->auth();
