@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC Email Domain commands
 ##
-## Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -20,7 +20,7 @@ package Net::DRI::Protocol::AFNIC::Email::Domain;
 use strict;
 use Net::DRI::Util;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -78,20 +78,14 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
-sub verify_rd
-{
- my ($rd,$key)=@_;
- return 0 unless (defined($key) && $key);
- return 0 unless (defined($rd) && (ref($rd) eq 'HASH') && exists($rd->{$key}) && defined($rd->{$key}));
- return 1;
-}
-
+## AFNIC says international format is : +code_pays 10 20 30 40 50 
+## yeah right !
 sub format_tel
 {
  my $in=shift;
  $in=~s/x.*$//;
- $in=~s/\./ /;
- return $in;
+ my @t=split(/\./,$in,2);
+ return $t[0].' '.reverse(join(' ',grep { defined($_) && $_ ne '' } split(/(\d{2})/,reverse($t[1]))));
 }
 
 sub add_starting_block
@@ -104,7 +98,7 @@ sub add_starting_block
  $mes->line('1c',$ca->{pw}); ## mot de passe
  $mes->line('1e',$mes->trid()); ## reference client (=trid) ## allow more/other ?
  $mes->line('1f','2.0.0');
- $mes->line('1g',$rd->{auth_code}) if ($action=~m/^[CD]$/ && verify_rd($rd,'auth_code') && $rd->{auth_code}); ## authorization code for reserved domain names
+ $mes->line('1g',$rd->{auth_code}) if ($action=~m/^[CD]$/ && Net::DRI::Util::has_key($rd,'auth_code') && $rd->{auth_code}); ## authorization code for reserved domain names
 
  $mes->line('2a',$domain);
 }
@@ -116,10 +110,10 @@ sub create
 
  add_starting_block('C',$domain,$mes,$rd);
  
- Net::DRI::Exception::usererr_insufficient_parameters("contacts are mandatory") unless (verify_rd($rd,'contact') && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet'));
+ Net::DRI::Exception::usererr_insufficient_parameters('contacts are mandatory') unless Net::DRI::Util::has_contact($rd);
  my $cs=$rd->{contact};
  my $co=$cs->get('registrant');
- Net::DRI::Exception::usererr_insufficient_parameters("registrant contact is mandatory") unless ($co && UNIVERSAL::isa($co,'Net::DRI::Data::Contact::AFNIC'));
+ Net::DRI::Exception::usererr_insufficient_parameters('registrant contact is mandatory') unless Net::DRI::Util::isa_contact($co,'Net::DRI::Data::Contact::AFNIC');
  $co->validate();
  $co->validate_is_french() unless ($co->roid()); ## registrant must be in France
 
@@ -130,7 +124,7 @@ sub create
   add_company_info($mes,$co);
  } else ## PP
  {
-  Net::DRI::Exception::usererr_insufficient_parameters("name or key needed for PP") unless ($co->name() || $co->key());
+  Net::DRI::Exception::usererr_insufficient_parameters('name or key needed for PP') unless ($co->name() || $co->key());
   if ($co->key())
   {
    $mes->line('3q',$co->key());
@@ -138,7 +132,7 @@ sub create
   {
    $mes->line('3a',$co->name());
    my $b=$co->birth();
-   Net::DRI::Exception::usererr_insufficient_parameters("birth data mandatory, if no registrant key provided") unless ($b && (ref($b) eq 'HASH') && exists($b->{date}) && exists($b->{place}));
+   Net::DRI::Exception::usererr_insufficient_parameters('birth data mandatory, if no registrant key provided') unless ($b && (ref($b) eq 'HASH') && exists($b->{date}) && exists($b->{place}));
    $mes->line('3r',(ref($b->{date}))? $b->{date}->strftime('%d/%m/%Y') : $b->{date});
    $mes->line('3s',$b->{place});
   }
@@ -149,23 +143,22 @@ sub create
  add_admin_contact($mes,$cs); ## optional
  add_tech_contacts($mes,$cs); ## mandatory
 
- Net::DRI::Exception::usererr_insufficient_parameters("at least 2 nameservers are mandatory") unless verify_rd($rd,'ns');
+ Net::DRI::Exception::usererr_insufficient_parameters('nameservers (at least 2) are mandatory for create') unless Net::DRI::Util::has_ns($rd);
  add_all_ns($domain,$mes,$rd->{ns});
-
- add_installation($mes,$rd->{installation_type},$rd->{form_type});
+ add_installation($mes,$rd);
 }
 
 sub add_company_info
 {
  my ($mes,$co)=@_;
  $mes->line('3a',$co->org());
- Net::DRI::Exception::usererr_insufficient_parameters("one legal form must be provided") unless ($co->legal_form() || $co->legal_form_other());
+ Net::DRI::Exception::usererr_insufficient_parameters('one legal form must be provided') unless ($co->legal_form() || $co->legal_form_other());
  $mes->line('3h',$co->legal_form())       if $co->legal_form();
  $mes->line('3i',$co->legal_form_other()) if $co->legal_form_other();
- Net::DRI::Exception::usererr_insufficient_parameters("legal id must be provided if no trademark") if (($co->legal_form() eq 'S') && !$co->trademark() && !$co->legal_id());
+ Net::DRI::Exception::usererr_insufficient_parameters('legal id must be provided if no trademark') if (($co->legal_form() eq 'S') && !$co->trademark() && !$co->legal_id());
  $mes->line('3j',$co->legal_id())         if $co->legal_id();
  my $jo=$co->jo();
- Net::DRI::Exception::usererr_insufficient_parameters("jo data is needed for non profit organization without legal id or trademark") if (($co->legal_form() eq 'A') && !$co->legal_id() && !$co->trademark() && (!$jo || (ref($jo) ne 'HASH') || !exists($jo->{date_publication}) || !exists($jo->{page})));
+ Net::DRI::Exception::usererr_insufficient_parameters('jo data is needed for non profit organization without legal id or trademark') if (($co->legal_form() eq 'A') && !$co->legal_id() && !$co->trademark() && (!$jo || (ref($jo) ne 'HASH') || !exists($jo->{date_publication}) || !exists($jo->{page})));
  if ($jo && (ref($jo) eq 'HASH'))
  {
   $mes->line('3k',$jo->{date_declaration}) if (exists($jo->{date_declaration}) && $jo->{date_declaration});
@@ -179,12 +172,14 @@ sub add_company_info
 
 sub add_installation
 {
- my ($mes,$installation,$form)=@_;
+ my ($mes,$rd)=@_;
 
  ## Default = A = waiting for client, otherwise I = direct installation
- $mes->line('8a',$installation) if (defined($installation) && $installation=~m/^[IA]$/);
+ my $inst=(Net::DRI::Util::has_key($rd,'installation_type') && $rd->{installation_type}=~m/^[IA]$/)? $rd->{installation_type} : 'A';
+ $mes->line('8a',$inst);
  ## S = standard = fax need to be sent, Default = E = Express = no fax
- $mes->line('9a',$form)         if (defined($form) && $form=~m/^[SE]$/);
+ my $form=(Net::DRI::Util::has_key($rd,'form_type') && $rd->{form_type}=~m/^[SE]$/)? $rd->{form_type} : 'E';
+ $mes->line('9a',$form);
 }
 
 sub add_owner_info
@@ -194,15 +189,15 @@ sub add_owner_info
  if ($co->org() || !$co->roid())
  {
   my $s=$co->street();
-  Net::DRI::Exception::usererr_insufficient_parameters("1 line of address at least needed if no nichandle") unless ($s && (ref($s) eq 'ARRAY') && @$s && $s->[0]);
+  Net::DRI::Exception::usererr_insufficient_parameters('1 line of address at least needed if no nichandle') unless ($s && (ref($s) eq 'ARRAY') && @$s && $s->[0]);
   $mes->line('3b',$s->[0]);
   $mes->line('3c',$s->[1]) if $s->[1];
   $mes->line('3d',$s->[2]) if $s->[2];
-  Net::DRI::Exception::usererr_insufficient_parameters("city, pc & cc mandatory if no nichandle") unless ($co->city() && $co->pc() && $co->cc());
+  Net::DRI::Exception::usererr_insufficient_parameters('city, pc & cc mandatory if no nichandle') unless ($co->city() && $co->pc() && $co->cc());
   $mes->line('3e',$co->city());
   $mes->line('3f',$co->pc());
   $mes->line('3g',uc($co->cc()));
-  Net::DRI::Exception::usererr_insufficient_parameters("voice & email mandatory if no nichandle") unless ($co->voice() && $co->email());
+  Net::DRI::Exception::usererr_insufficient_parameters('voice & email mandatory if no nichandle') unless ($co->voice() && $co->email());
   $mes->line('3t',format_tel($co->voice()));
   $mes->line('3u',format_tel($co->fax())) if $co->fax();
   $mes->line('3v',$co->email());
@@ -215,9 +210,9 @@ sub add_owner_info
 sub add_maintainer_disclose
 {
  my ($mes,$co,$maintainer)=@_;
- Net::DRI::Exception::usererr_insufficient_parameters("maintainer mandatory if no nichandle") unless (defined($maintainer) && $maintainer=~m/^[A-Z0-9][-A-Z0-9]+[A-Z0-9]$/i);
+ Net::DRI::Exception::usererr_insufficient_parameters('maintainer mandatory if no nichandle') unless (defined($maintainer) && $maintainer=~m/^[A-Z0-9][-A-Z0-9]+[A-Z0-9]$/i);
  $mes->line('3y',$maintainer);
- Net::DRI::Exception::usererr_insufficient_parameters("disclose option is mandatory if no nichandle") unless ($co->disclose());
+ Net::DRI::Exception::usererr_insufficient_parameters('disclose option is mandatory if no nichandle') unless ($co->disclose());
  $mes->line('3z',$co->disclose());
 }
 
@@ -225,14 +220,14 @@ sub add_admin_contact
 {
  my ($mes,$cs)=@_;
  my $co=$cs->get('admin');
- $mes->line('4a',$co->roid()) if ($co && UNIVERSAL::isa($co,'Net::DRI::Data::Contact') && $co->roid());
+ $mes->line('4a',$co->roid()) if (Net::DRI::Util::isa_contact($co) && $co->roid());
 }
 
 sub add_tech_contacts
 {
  my ($mes,$cs)=@_;
- my @co=map { $_->roid() } grep { UNIVERSAL::isa($_,'Net::DRI::Data::Contact') } $cs->get('tech');
- Net::DRI::Exception::usererr_insufficient_parameters("at least one technical contact is mandatory") unless @co;
+ my @co=map { $_->roid() } grep { Net::DRI::Util::isa_contact($_) } $cs->get('tech');
+ Net::DRI::Exception::usererr_insufficient_parameters('at least one technical contact is mandatory') unless @co;
  $mes->line('5a',$co[0]);
  $mes->line('5c',$co[1]) if $co[1];
  $mes->line('5e',$co[2]) if $co[2];
@@ -241,7 +236,7 @@ sub add_tech_contacts
 sub add_all_ns
 {
  my ($domain,$mes,$ns)=@_;
- Net::DRI::Exception::usererr_insufficient_parameters("at least 2 nameservers are mandatory") unless (defined($ns) && ref($ns) && UNIVERSAL::isa($ns,'Net::DRI::Data::Hosts') && !$ns->is_empty() && $ns->count()>=2);
+ Net::DRI::Exception::usererr_insufficient_parameters('at least 2 nameservers are mandatory') unless (Net::DRI::Util::isa_hosts($ns,'Net::DRI::Data::Hosts') && $ns->count()>=2);
 
  add_one_ns($mes,$ns,1,$domain,'6a','6b');
  add_one_ns($mes,$ns,2,$domain,'7a','7b');
@@ -270,7 +265,7 @@ sub delete
  my $mes=$a->message();
 
  add_starting_block('S',$domain,$mes,$rd);
- add_installation($mes,$rd->{installation_type},$rd->{form_type});
+ add_installation($mes,$rd);
 }
 
 sub update
@@ -291,8 +286,8 @@ sub update
  my $ns=$todo->set('ns');
  my $cs=$todo->set('contact');
 
- my $wc=defined($cs) && ref($cs) && UNIVERSAL::isa($cs,'Net::DRI::Data::ContactSet');
- Net::DRI::Exception::usererr_invalid_parameters("can not change both admin & tech contacts at the same time") if ($wc && $cs->has_type('tech') && ($cs->has_type('admin') || $cs->has_type('registrant')));
+ my $wc=Net::DRI::Util::isa_contactset($cs);
+ Net::DRI::Exception::usererr_invalid_parameters('can not change both admin & tech contacts at the same time') if ($wc && $cs->has_type('tech') && ($cs->has_type('admin') || $cs->has_type('registrant')));
 
  ## Technical change (DNS / Tech contacts)
  if ($wc && $cs->has_type('tech'))
@@ -300,7 +295,7 @@ sub update
   add_starting_block('T',$domain,$mes); ## no $rd here !
   add_tech_contacts($mes,$cs); ##  tech contacts mandatory even for only nameserver changes !
   add_all_ns($domain,$mes,$ns);
-  add_installation($mes,$rd->{installation_type},$rd->{form_type}) if (defined($rd) && (ref($rd) eq 'HASH'));
+  add_installation($mes,$rd);
   return;
  }
 
@@ -309,18 +304,18 @@ sub update
  {
   add_starting_block('A',$domain,$mes);
   my $co=$cs->get('registrant');
-  if (defined($co) && UNIVERSAL::isa($co,'Net::DRI::Data::Contact') && $co->org()) ## only for PM
+  if (Net::DRI::Util::isa_contact($co) && $co->org()) ## only for PM
   {
    $co->validate();
+   $mes->line('3a',$co->org());
    add_owner_info($mes,$co);
   } else
   {
    my $ca=$cs->get('admin');
-   Net::DRI::Exception::usererr_insufficient_parameters("contact admin is mandatory for PP admin change") unless ($ca && UNIVERSAL::isa($ca,'Net::DRI::Data::Contact') && $ca->roid());
+   Net::DRI::Exception::usererr_insufficient_parameters('contact admin is mandatory for PP admin change') unless (Net::DRI::Util::isa_contact($ca) && $ca->roid());
   }
   add_admin_contact($mes,$cs);
-
-  add_installation($mes,$rd->{installation_type},$rd->{form_type}) if (defined($rd) && (ref($rd) eq 'HASH'));
+  add_installation($mes,$rd);
   return;
  } 
 
@@ -334,7 +329,7 @@ sub trade
 
  create($a,$domain,$rd);
  $mes->line('1a','P');
- $mes->line('1h',$rd->{trade_type}) if (verify_rd($rd,'trade_type') && $rd->{trade_type}=~m/^[VF]$/);
+ $mes->line('1h',(Net::DRI::Util::has_key($rd,'trade_type') && $rd->{trade_type}=~m/^[VF]$/)? $rd->{trade_type} : 'V');
 }
 
 sub transfer_request
@@ -344,10 +339,10 @@ sub transfer_request
 
  add_starting_block('D',$domain,$mes,$rd);
  Net::DRI::Exception::usererr_invalid_parameters() unless (defined($rd) && (ref($rd) eq 'HASH') && keys(%$rd));
- Net::DRI::Exception::usererr_insufficient_parameters("contacts are mandatory") unless (verify_rd($rd,'contact') && UNIVERSAL::isa($rd->{contact},'Net::DRI::Data::ContactSet'));
+ Net::DRI::Exception::usererr_insufficient_parameters('contacts are mandatory') unless Net::DRI::Util::has_contact($rd);
  my $cs=$rd->{contact};
  my $co=$cs->get('registrant');
- Net::DRI::Exception::usererr_insufficient_parameters("registrant contact is mandatory") unless ($co && UNIVERSAL::isa($co,'Net::DRI::Data::Contact::AFNIC'));
+ Net::DRI::Exception::usererr_insufficient_parameters('registrant contact is mandatory') unless Net::DRI::Util::isa_contact($co,'Net::DRI::Data::Contact::AFNIC');
  $co->validate();
  $co->validate_is_french() unless ($co->roid()); ## registrant must be in France
 
@@ -356,13 +351,13 @@ sub transfer_request
   add_company_info($mes,$co);
  } else ## PP
  {
-  Net::DRI::Exception::usererr_insufficient_parameters("key mandatory for PP") unless ($co->key());
+  Net::DRI::Exception::usererr_insufficient_parameters('key mandatory for PP') unless ($co->key());
   $mes->line('3q',$co->key());
  }
 
  add_tech_contacts($mes,$cs); ##  tech contacts mandatory
  add_all_ns($domain,$mes,$rd->{ns}); ## ns mandatory
- add_installation($mes,$rd->{installation_type},$rd->{form_type});
+ add_installation($mes,$rd);
 }
 
 ####################################################################################################
