@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC Web Services Protocol
 ##
-## Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -13,7 +13,7 @@
 #
 # 
 #
-#########################################################################################
+####################################################################################################
 
 package Net::DRI::Protocol::AFNIC::WS;
 
@@ -26,7 +26,7 @@ use Net::DRI::Util;
 
 use Net::DRI::Protocol::AFNIC::WS::Message;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -56,7 +56,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -68,26 +68,15 @@ See the LICENSE file that comes with this distribution for more details.
 
 =cut
 
-###################################################################################################
+####################################################################################################
 
 sub new
 {
- my $h=shift;
- my $c=ref($h) || $h;
-
- my ($drd,$version,$extrah)=@_;
-
- my $self=$c->SUPER::new(); ## we are now officially a Net::DRI::Protocol object
+ my ($c,$drd,$version,$extrah)=@_;
+ my $self=$c->SUPER::new();
  $self->name('afnic_ws');
  $self->version($VERSION);
-
- $self->capabilities({});
-
- $self->factories({ message => sub { my $m=Net::DRI::Protocol::AFNIC::WS::Message->new(); $m->version($VERSION); return $m; },
-                  });
-
- bless($self,$c); ## rebless
-
+ $self->factories('message',sub { my $m=Net::DRI::Protocol::AFNIC::WS::Message->new(); $m->version($VERSION); return $m; });
  $self->_load($extrah);
  return $self;
 }
@@ -95,12 +84,9 @@ sub new
 sub _load
 {
  my ($self,$extrah)=@_;
-
- my @class=map { "Net::DRI::Protocol::AFNIC::WS::".$_ } ('Domain');
-
+ my @class=map { 'Net::DRI::Protocol::AFNIC::WS::'.$_ } ('Domain');
  $self->SUPER::_load(@class);
 }
 
-
-##########################################################################################################
+####################################################################################################
 1;
