@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Connection handling
 ##
-## Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -18,16 +18,19 @@
 package Net::DRI::Protocol::EPP::Connection;
 
 use strict;
+
 use Net::DRI::Data::Raw;
 use Net::DRI::Protocol::ResultStatus;
 
-our $VERSION=do { my @r=(q$Revision: 1.13 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+use Encode ();
+
+our $VERSION=do { my @r=(q$Revision: 1.14 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Connection - EPP Connection handling (RFC4934) for Net::DRI
+Net::DRI::Protocol::EPP::Connection - EPP over TCP connection handling (RFC4934) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -51,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2007 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,8 +70,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub login
 {
- shift if ($_[0] eq __PACKAGE__);
- my ($cm,$id,$pass,$cltrid,$dr,$newpass,$pdata)=@_;
+ my ($class,$to,$cm,$id,$pass,$cltrid,$dr,$newpass,$pdata)=@_;
 
  my $got=$cm->();
  $got->parse($dr);
@@ -90,38 +92,35 @@ sub login
 
  $mes->command_body(\@d);
  $mes->cltrid($cltrid) if $cltrid;
- return $mes->as_string('tcp');
+ return $class->write_message($to,$mes);
 }
 
 sub logout
 {
- shift if ($_[0] eq __PACKAGE__);
- my ($cm,$cltrid)=@_;
+ my ($class,$to,$cm,$cltrid)=@_;
  my $mes=$cm->();
  $mes->command(['logout']);
  $mes->cltrid($cltrid) if $cltrid;
- return $mes->as_string('tcp');
+ return $class->write_message($to,$mes);
 }
 
 sub keepalive
 {
- shift if ($_[0] eq __PACKAGE__);
- my ($cm,$cltrid)=@_;
+ my ($class,$to,$cm)=@_;
  my $mes=$cm->();
  $mes->command(['hello']);
- return $mes->as_string('tcp');
+ return $class->write_message($to,$mes);
 }
 
 ####################################################################################################
 
-sub get_data
+sub read_data
 {
- shift if ($_[0] eq __PACKAGE__);
- my ($to,$sock)=@_;
+ my ($class,$to,$sock)=@_;
 
  my $c;
  $sock->read($c,4); ## first 4 bytes are the packed length
- die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR','Unable to read EPP 4 bytes length (connection closed by registry ?)','en')) unless $c;
+ die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_FAILED','Unable to read EPP 4 bytes length (connection closed by registry ?)','en')) unless $c;
  my $length=unpack('N',$c)-4;
  my ($m);
  while ($length > 0)
@@ -130,15 +129,23 @@ sub get_data
   $length-=$sock->read($new,$length);
   $m.=$new;
  }
- die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR',$m? $m : '<empty message from server>','en')) unless ($m=~m!</epp>$!);
+ die(Net::DRI::Protocol::ResultStatus->new_error('COMMAND_SYNTAX_ERROR',$m? $m : '<empty message from server>','en')) unless ($m=~m!</epp>\r?$!);
 
  return Net::DRI::Data::Raw->new_from_string($m);
 }
 
+sub write_message
+{
+ my ($self,$to,$msg)=@_;
+
+ my $m=Encode::encode('utf8',$msg->as_string());
+ my $l=pack('N',4+length($m)); ## RFC 4934 4
+ return $l.$m; ## We do not support EPP 0.4 at all (which lacks length before data)
+}
+
 sub parse_greeting
 {
- shift if ($_[0] eq __PACKAGE__);
- my $dc=shift;
+ my ($class,$dc)=@_;
  my ($code,$msg,$lang)=find_code($dc);
  unless (defined($code) && ($code==1000))
  {
@@ -157,8 +164,7 @@ sub parse_keepalive
 
 sub parse_login
 {
- shift if ($_[0] eq __PACKAGE__);
- my $dc=shift;
+ my ($class,$dc)=@_;
  my ($code,$msg,$lang)=find_code($dc);
  unless (defined($code) && ($code==1000))
  {
@@ -172,8 +178,7 @@ sub parse_login
 
 sub parse_logout
 {
- shift if ($_[0] eq __PACKAGE__);
- my $dc=shift;
+ my ($class,$dc)=@_;
  my ($code,$msg,$lang)=find_code($dc);
  unless (defined($code) && ($code==1500))
  {
