@@ -1,7 +1,7 @@
-## Domain Registry Interface, AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) EPP extensions
-## From http://www.afnic.fr/medias/documents/afnic-guide-integration-technique.pdf (v1.55 2011-03-03)
+## Domain Registry Interface, AFNIC (.FR/.RE) EPP extensions
+## From http://www.afnic.fr/data/divers/public/afnic-epp-rc1.pdf (2008-06-30)
 ##
-## Copyright (c) 2008,2009,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -11,23 +11,27 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AFNIC;
 
 use strict;
-use warnings;
 
 use base qw/Net::DRI::Protocol::EPP/;
 
 use Net::DRI::Data::Contact::AFNIC;
 use Net::DRI::Protocol::EPP::Extensions::AFNIC::Status;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::AFNIC - AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) EPP extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::AFNIC - AFNIC (.FR/.RE) EPP extensions for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -51,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,23 +69,26 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-sub setup
+sub new
 {
- my ($self,$rp)=@_;
- $self->ns({frnic => 'http://www.afnic.fr/xml/epp/frnic-1.4'});
+ my ($c,$drd,$version,$extrah)=@_;
+ my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
+
+ $e{'Net::DRI::Protocol::EPP::Extensions::AFNIC::Domain'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::AFNIC::Contact'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::AFNIC::Notifications'}=1;
+ $e{'Net::DRI::Protocol::EPP::Extensions::GracePeriod'}=1;
+
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ $self->ns({frnic=>['http://www.afnic.fr/xml/epp/frnic-1.0','frnic-1.0.xsd']}); ## fake xsd for now
  $self->capabilities('domain_update','registrant',undef); ## a trade is required
  $self->capabilities('contact_update','status',undef); ## No changes in status possible for .FR contacts
  $self->capabilities('contact_update','disclose',['add','del']);
- $self->capabilities('contact_update','qualification',['add','del']);
- $self->capabilities('domain_update','secdns',['add','del']); ## no chg allowed for maxSigLife
- $self->capabilities('domain_update','secdns_urgent',undef); ## no urgent attribute allowed
  $self->factories('contact',sub { return Net::DRI::Data::Contact::AFNIC->new(); });
  $self->factories('status',sub { return Net::DRI::Protocol::EPP::Extensions::AFNIC::Status->new(); });
- return;
+ $self->default_parameters({domain_create => { ns => undef } }); ## No nameservers allowed during domain create
+ return $self;
 }
 
-sub core_contact_types { return ('admin','tech'); } ## No billing contact in .FR
-sub default_extensions { return qw/AFNIC::Session AFNIC::Domain AFNIC::Contact AFNIC::Notifications GracePeriod SecDNS/; }
-
 ####################################################################################################
 1;
