@@ -1,6 +1,6 @@
 ## Domain Registry Interface, AFNIC EPP Domain extensions
 ##
-## Copyright (c) 2008-2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,22 +10,26 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::AFNIC::Domain;
 
 use strict;
-use warnings;
-use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
+use DateTime::Format::ISO8601;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::AFNIC::Domain - AFNIC (.FR/.RE/.TF/.WF/.PM/.YT) EPP Domain extensions for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::AFNIC::Domain - AFNIC (.FR/.RE) EPP Domain extensions for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -49,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,41 +70,42 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- state $rops = { domain => {
-                            create           => [ \&create, undef ],
-                            update           => [ \&update, undef ],
-                            transfer_request => [ \&transfer_request, undef ],
-                            trade_request    => [ \&trade_request, \&trade_parse ],
-                            trade_query      => [ \&trade_query,   \&trade_parse ],
-                            trade_cancel     => [ \&trade_cancel,  undef ],
-                            recover_request  => [ \&recover_request, \&recover_parse],
-                            check            => [ undef, \&check_parse],
-                            check_multi      => [ undef, \&check_parse],
-                            info             => [ undef, \&info_parse],
-                           }
-               };
+ my %tmp=(
+           update => [ \&update, undef ],
+           transfer_request => [ \&transfer_request, undef ],
+           trade_request     => [ \&trade_request, \&trade_parse ],
+           trade_query      => [ \&trade_query , \&trade_parse ],
+           recover_request => [ \&recover_request, \&recover_parse],
+           check => [ undef, \&check_parse],
+           info => [ undef, \&info_parse],
+         );
 
- return $rops;
+ $tmp{check_multi}=$tmp{check};
+ return { 'domain' => \%tmp };
 }
 
 ####################################################################################################
 
+sub build_command_extension
+{
+ my ($mes,$epp,$tag)=@_;
+ return $mes->command_extension_register($tag,sprintf('xmlns:frnic="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('frnic')));
+}
+
 sub build_domain
 {
  my ($domain)=@_;
  Net::DRI::Exception->die(1,'protocol/EPP',2,'Domain name needed') unless defined($domain) && $domain;
  Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
  return ['frnic:name',$domain];
-}
+ }
 
 sub build_registrant
 {
  my ($rd)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs contacts for domain operations') unless Net::DRI::Util::has_contact($rd);
+ Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs contact for domain_trade') unless Net::DRI::Util::has_contact($rd);
  my @t=$rd->{contact}->get('registrant');
- Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs one contact of type registrant') unless (@t==1 && Net::DRI::Util::isa_contact($t[0],'Net::DRI::Data::Contact::AFNIC'));
- $t[0]->validate_registrant();
- Net::DRI::Exception::usererr_invalid_parameters('Registrant contact must have an id') unless length $t[0]->srid();
+ Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs one contact of type registrant') unless (@t==1 && Net::DRI::Util::isa_contact($t[0]));
  return ['frnic:registrant',$t[0]->srid()];
 }
 
@@ -113,13 +118,12 @@ sub build_cltrid
 sub verify_contacts
 {
  my $rd=shift;
- Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs contacts for domain operations') unless Net::DRI::Util::has_contact($rd);
+ Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs contact for domain_transfer/domain_trade') unless Net::DRI::Util::has_contact($rd);
  my @t=$rd->{contact}->get('admin');
- Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs one contact of type admin, and only one') unless (@t==1 && Net::DRI::Util::isa_contact($t[0],'Net::DRI::Data::Contact::AFNIC'));
- @t=grep { Net::DRI::Util::isa_contact($_,'Net::DRI::Data::Contact::AFNIC') } $rd->{contact}->get('tech');
+ Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs only one contact of type admin') unless (@t==1 && Net::DRI::Util::isa_contact($t[0]));
+ @t=grep { Net::DRI::Util::isa_contact($_) } $rd->{contact}->get('tech');
  Net::DRI::Exception::usererr_invalid_parameters('AFNIC needs one to three contacts of type tech') unless (@t >= 1 && @t <= 3);
- return;
-}
+ }
 
 sub build_contacts
 {
@@ -131,24 +135,6 @@ sub build_contacts
  return @n;
 }
 
-sub build_authinfo
-{
- my ($mes, $rd, $what)=@_;
- Net::DRI::Exception::usererr_invalid_parameters('authInfo is mandatory for a "'.$what.'"') unless (Net::DRI::Util::has_auth($rd) && exists($rd->{auth}->{pw}) && $rd->{auth}->{pw});
- return ['frnic:authInfo',['domain:pw',{'xmlns:domain'=>$mes->ns('domain')},$rd->{auth}->{pw}]];
-}
-
-sub create
-{
- my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
-
- ## We just make sure that we have all contact data
- verify_contacts($rd);
- build_registrant($rd);
- return;
-}
-
 sub update
 {
  my ($epp,$domain,$todo)=@_;
@@ -159,25 +145,16 @@ sub update
  return unless (defined($rgp) && $rgp && (ref($rgp) eq 'HASH'));
  my $op=$rgp->{op} || '';
  Net::DRI::Exception::usererr_invalid_parameters('RGP op can only be request for AFNIC') unless ($op eq 'request');
- return;
-}
-
-sub add_keepds
-{
- my ($op,$rd)=@_;
- Net::DRI::Exception::usererr_insufficient_parameters('Domain "'.$op.'" operation needs a keep_ds attribute') unless Net::DRI::Util::has_key($rd,'keep_ds');
- Net::DRI::Exception::usererr_invalid_parameters('keep_ds attribute must be boolean, not '.$rd->{keep_ds}) unless Net::DRI::Util::xml_is_boolean($rd->{keep_ds});
-
- return { 'keepDS' => $rd->{keep_ds} };
 }
 
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
+ my $mes=$epp->message();
 
  verify_contacts($rd);
- $epp->message()->command_extension('frnic', ['ext', ['transfer', ['domain', add_keepds('transfer',$rd), build_contacts($rd)]]]);
- return;
+ my $eid=build_command_extension($mes,$epp,'frnic:ext');
+ $mes->command_extension($eid,['frnic:transfer',['frnic:domain',build_contacts($rd)]]);
 }
 
 sub parse_trade_recover
@@ -186,32 +163,39 @@ sub parse_trade_recover
  my $mes=$po->message();
 
  my $infdata=$mes->get_extension('frnic','ext');
- return unless defined $infdata;
-
+ return unless $infdata;
  my $ns=$mes->ns('frnic');
- $infdata=Net::DRI::Util::xml_traverse($infdata,$ns,'resData',$s,'domain');
- return unless defined $infdata;
+ my $c=$infdata->getChildrenByTagNameNS($ns,'resData');
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,$s);
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,'domain');
+ return unless $c->size();
 
- foreach my $el (Net::DRI::Util::xml_list_children($infdata))
+ my $pd=DateTime::Format::ISO8601->new();
+ $c=$c->shift()->getFirstChild();
+ while($c)
  {
-  my ($name,$c)=@$el;
+  next unless ($c->nodeType() == 1); ## only for element nodes
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
+
   if ($name eq 'name')
   {
-   $oname=lc($c->textContent());
+   $oname=lc($c->getFirstChild()->getData());
    $rinfo->{domain}->{$oname}->{action}=$oaction;
    $rinfo->{domain}->{$oname}->{exist}=1;
   } elsif ($name eq 'trStatus')
   {
-   $rinfo->{domain}->{$oname}->{$name}=$c->textContent();
+   $rinfo->{domain}->{$oname}->{$name}=$c->getFirstChild()->getData();
   } elsif ($name=~m/^(reID|reHldID|acID|acHldID)$/)
   {
-   $rinfo->{domain}->{$oname}->{$name}=$c->textContent();
+   $rinfo->{domain}->{$oname}->{$name}=$c->getFirstChild()->getData();
   } elsif ($name=~m/^(reDate|rhDate|ahDate)$/)
   {
-   $rinfo->{domain}->{$oname}->{$name}=$po->parse_iso8601($c->textContent());
+   $rinfo->{domain}->{$oname}->{$name}=$pd->parse_datetime($c->getFirstChild()->getData());
   }
- }
- return;
+ } continue { $c=$c->getNextSibling(); }
 }
 
 sub trade_request
@@ -219,56 +203,43 @@ sub trade_request
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
 
+ my $eid=build_command_extension($mes,$epp,'frnic:ext');
  my @n=build_domain($domain);
  push @n,build_registrant($rd);
- push @n,build_authinfo($mes, $rd, 'trade request');
- $mes->command_extension('frnic', ['ext', ['command', ['trade', {op=>'request'}, ['domain', @n]], build_cltrid($mes)]]);
- return;
+ push @n,build_contacts($rd);
+ $mes->command_extension($eid,['frnic:command',['frnic:trade',{op=>'request'},['frnic:domain',@n]],build_cltrid($mes)]);
 }
 
 sub trade_query
 {
  my ($epp,$domain,$rd)=@_;
  my $mes=$epp->message();
-
+ my $eid=build_command_extension($mes,$epp,'frnic:ext');
  my @n=build_domain($domain);
- push @n,build_authinfo($mes, $rd, 'trade query');
- $mes->command_extension('frnic', ['ext', ['command', ['trade', {op=>'query'}, ['domain', @n]], build_cltrid($mes)]]);
- return;
-}
-
-sub trade_cancel
-{
- my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
-
- my @n=build_domain($domain);
- push @n,build_authinfo($mes, $rd, 'trade cancel');
- $mes->command_extension('frnic', ['ext', ['command', ['trade', {op=>'cancel'}, ['domain', @n]], build_cltrid($mes)]]);
- return;
+ $mes->command_extension($eid,['frnic:command',['frnic:trade',{op=>'query'},['frnic:domain',@n]],build_cltrid($mes)]);
 }
 
 sub trade_parse
 {
- my ($po,$otype,$oaction,$oname,$rinfo)=@_;
+  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
  return unless $mes->is_success();
 
  parse_trade_recover($po,$otype,'trade',$oname,$rinfo,'trdData');
- return;
 }
 
 sub recover_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
+ my $mes=$epp->message(); 
 
+ my $eid=build_command_extension($mes,$epp,'frnic:ext');
  my @n=build_domain($domain);
- push @n,build_authinfo($mes, $rd, 'recover request');
+ Net::DRI::Exception::usererr_invalid_parameters('authInfo is mandatory for a recover request') unless (Net::DRI::Util::has_auth($rd) && exists($rd->{auth}->{pw}) && $rd->{auth}->{pw});
+ push @n,['frnic:authInfo',['frnic:pw',$rd->{auth}->{pw}]];
  push @n,build_registrant($rd);
  push @n,build_contacts($rd);
- $mes->command_extension('frnic', ['ext', ['command', ['recover', {op=>'request'}, ['domain', add_keepds('recover', $rd), @n]], build_cltrid($mes)]]);
- return;
+ $mes->command_extension($eid,['frnic:command',['frnic:recover',{op=>'request'},['frnic:domain',@n]],build_cltrid($mes)]);
 }
 
 sub recover_parse
@@ -278,7 +249,6 @@ sub recover_parse
  return unless $mes->is_success();
 
  parse_trade_recover($po,$otype,'recover',$oname,$rinfo,'recData');
- return;
 }
 
 sub check_parse
@@ -288,38 +258,41 @@ sub check_parse
  return unless $mes->is_success();
 
  my $chkdata=$mes->get_extension('frnic','ext');
- return unless defined $chkdata;
-
+ return unless $chkdata;
  my $ns=$mes->ns('frnic');
- $chkdata=Net::DRI::Util::xml_traverse($chkdata,$ns,'resData','chkData','domain');
- return unless defined $chkdata;
+ my $c=$chkdata->getChildrenByTagNameNS($ns,'resData');
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,'chkData');
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,'domain');
+ return unless $c->size();
 
- foreach my $cd ($chkdata->getChildrenByTagNameNS($ns,'cd'))
+ foreach my $cd ($c->shift()->getChildrenByTagNameNS($ns,'cd'))
  {
+  my $c=$cd->getFirstChild();
   my (@r,@f,$domain);
-  foreach my $el (Net::DRI::Util::xml_list_children($cd))
+  while($c)
   {
-   my ($n,$c)=@$el;
+   next unless ($c->nodeType() == 1); ## only for element nodes
+   my $n=$c->localname() || $c->nodeName();
    if ($n eq 'name')
    {
-    $domain=lc($c->textContent());
+    $domain=lc($c->getFirstChild()->getData());
     $rinfo->{domain}->{$domain}->{action}='check';
-    $rinfo->{domain}->{$domain}->{reserved}=Net::DRI::Util::xml_parse_boolean($c->getAttribute('reserved'));
-    $rinfo->{domain}->{$domain}->{forbidden}=Net::DRI::Util::xml_parse_boolean($c->getAttribute('forbidden'));
+    ## attributes reserved/forbidden are not used since they just tell if rsvReason/fbdReason are there
    } elsif ($n eq 'rsvReason')
    {
-    push @r,$c->textContent();
+    push @r,$c->getFirstChild()->getData();
    } elsif ($n eq 'fbdReason')
    {
-    push @f,$c->textContent();
+    push @f,$c->getFirstChild()->getData();
    }
-  }
+  } continue { $c=$c->getNextSibling(); }
 
   ## There may be multiple of them !
-  $rinfo->{domain}->{$domain}->{reserved_reason}=join("\n",@r) if @r;
-  $rinfo->{domain}->{$domain}->{forbidden_reason}=join("\n",@f) if @f;
- }
- return;
+  $rinfo->{domain}->{$domain}->{reserved_reason}=join("\n",@r);
+  $rinfo->{domain}->{$domain}->{forbidden_reason}=join("\n",@f);
+ } ## end of foreach
 }
 
 sub info_parse
@@ -329,19 +302,22 @@ sub info_parse
  return unless $mes->is_success();
 
  my $infdata=$mes->get_extension('frnic','ext');
- return unless defined $infdata;
-
+ return unless $infdata;
  my $ns=$mes->ns('frnic');
- $infdata=Net::DRI::Util::xml_traverse($infdata,$ns,'resData','infData','domain');
- return unless defined $infdata;
+ my $c=$infdata->getChildrenByTagNameNS($ns,'resData');
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,'infData');
+ return unless $c->size();
+ $c=$c->shift()->getChildrenByTagNameNS($ns,'domain');
+ return unless $c->size();
 
  my $cs=$rinfo->{domain}->{$oname}->{status}; ## a Net::DRI::Protocol::EPP::Extensions::AFNIC::Status object
- foreach my $el ($infdata->getChildrenByTagNameNS($ns,'status'))
+ foreach my $el ($c->shift()->getChildrenByTagNameNS($mes->ns('frnic'),'status'))
  {
   $cs->rem('ok');
   $cs->add($el->getAttribute('s'));
  }
- return;
+
 }
 
 ####################################################################################################
