@@ -22,7 +22,7 @@ use strict;
 use Net::DRI::Data::Contact::ASIA;
 use base qw/Net::DRI::Protocol::EPP/;
 
-our $VERSION=do { my @r=(q$Revision: 1.2 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -68,10 +68,7 @@ See the LICENSE file that comes with this distribution for more details.
 ####################################################################################################
 sub new
 {
- my $h=shift;
- my $c=ref($h) || $h;
-
- my ($drd,$version,$extrah,$defproduct)=@_;
+ my ($c,$drd,$version,$extrah,$defproduct)=@_;
  my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
  if (exists($e{':full'})) ## useful shortcut, modeled after Perl itself
@@ -82,19 +79,13 @@ sub new
   $e{'Net::DRI::Protocol::EPP::Extensions::ASIA::CED'}=1;
  }
 
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
-
- if (exists($e{'Net::DRI::Protocol::EPP::Extensions::ASIA::CED'}))
- {
-  my $rfact=$self->factories();
-  $rfact->{contact}=sub { return Net::DRI::Data::Contact::ASIA->new(@_); };
- }
-
- my $rcapa = $self->capabilities();
- $rcapa->{domain_update}->{url} = ['set'];
- $rcapa->{domain_update}->{contact} = ['add','set','del'];
-
- bless($self,$c); ## rebless
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ $self->ns({ asia => ['urn:afilias:params:xml:ns:asia-1.0','asia-1.0.xsd'],
+             ipr  => ['urn:afilias:params:xml:ns:ipr-1.0','ipr-1.0.xsd'],  
+           });
+ $self->factories('contact',sub { return Net::DRI::Data::Contact::ASIA->new(@_); }) if (exists($e{'Net::DRI::Protocol::EPP::Extensions::ASIA::CED'}));
+ $self->capabilities('domain_update','url',['set']);
+ $self->capabilities('domain_update','contact',['add','set','del']);
  return $self;
 }
 
