@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP E.164 Validation Information Example from RFC5076
 ##
-## Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,19 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::E164Validation::RFC5076;
 
 use strict;
-use warnings;
-
 use Net::DRI::Exception;
 use Net::DRI::Util;
+use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 our $NS='urn:ietf:params:xml:ns:e164valex-1.1';
 
 =pod
@@ -50,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -74,18 +77,22 @@ sub info_parse
  my ($class,$po,$top)=@_;
  Net::DRI::Exception::usererr_insufficient_parameters('Root element for information validation of URI='.$NS.' must be simpleVal') unless (($top->localname() || $top->nodeName()) eq 'simpleVal');
 
+ my $pd=DateTime::Format::ISO8601->new();
+ my $c=$top->getFirstChild();
  my %n;
- foreach my $el (Net::DRI::Util::xml_list_children($top))
+ while ($c)
  {
-  my ($name,$c)=@$el;
+  next unless ($c->nodeType() == 1); ## only for element nodes
+  my $name=$c->localname() || $c->nodeName();
+  next unless $name;
   if ($name=~m/^(methodID|validationEntityID|registrarID)$/)
   {
-   $n{Net::DRI::Util::remcam($1)}=$c->textContent();
+   $n{Net::DRI::Util::remcam($1)}=$c->getFirstChild()->getData();
   } elsif ($name=~m/^(executionDate|expirationDate)$/)
   {
-   $n{Net::DRI::Util::remcam($1)}=$po->parse_iso8601($c->textContent());
+   $n{Net::DRI::Util::remcam($1)}=$pd->parse_datetime($c->getFirstChild()->getData());
   }
- }
+ } continue { $c=$c->getNextSibling(); }
  return \%n;
 }
 
@@ -93,7 +100,7 @@ sub output_date
 {
  my $d=shift;
  return unless defined($d);
- if (Net::DRI::Util::is_class($d,'DateTime'))
+ if (UNIVERSAL::isa($d,'DateTime'))
  {
   return $d->strftime('%Y-%m-%d');
  } else
@@ -108,16 +115,16 @@ sub create
  my ($class,$rd)=@_;
 
  my @c;
- Net::DRI::Exception::usererr_insufficient_parameters('method_id and execution_date are mandatory in validation information') unless (exists $rd->{method_id} && exists $rd->{execution_date});
+ Net::DRI::Exception::usererr_insufficient_parameters('method_id and execution_date are mandatory in validation information') unless (exists($rd->{method_id}) && exists($rd->{execution_date}));
  Net::DRI::Exception::usererr_invalid_parameters('method_id must be an xml token from 1 to 63 characters') unless Net::DRI::Util::xml_is_token($rd->{method_id},1,63);
  push @c,['valex:methodID',$rd->{method_id}];
 
- if (exists $rd->{validation_entity_id})
+ if (exists($rd->{validation_entity_id}))
  {
   Net::DRI::Exception::usererr_invalid_parameters('validation_entity_id must be an xml token from 3 to 16 characters') unless Net::DRI::Util::xml_is_token($rd->{validation_entity_id},3,16);
   push @c,['valex:validationEntityID',$rd->{validation_entity_id}];
  }
- if (exists $rd->{registrar_id})
+ if (exists($rd->{registrar_id}))
  {
   Net::DRI::Exception::usererr_invalid_parameters('registrar_id must be an xml token from 3 to 16 characters') unless Net::DRI::Util::xml_is_token($rd->{registrar_id},3,16);
   push @c,['valex:registrarID',$rd->{registrar_id}];
@@ -127,7 +134,7 @@ sub create
  Net::DRI::Exception::usererr_invalid_parameters('execution_date must be a DateTime object or a string like YYYY-MM-DD') unless defined($d);
  push @c,['valex:executionDate',$d];
 
- if (exists $rd->{expiration_date})
+ if (exists($rd->{expiration_date}))
  {
   $d=output_date($rd->{expiration_date});
   Net::DRI::Exception::usererr_invalid_parameters('expiration_date must be a DateTime object or a string like YYYY-MM-DD') unless defined($d);
@@ -137,9 +144,9 @@ sub create
  return ['valex:simpleVal',{'xmlns:valex' => $NS},@c];
 }
 
-sub renew    { my (@args)=@_; return create(@args); }
-sub transfer { my (@args)=@_; return create(@args); }
-sub update   { my (@args)=@_; return create(@args); }
+sub renew { return create(@_); }
+sub transfer { return create(@_); }
+sub update { return create(@_); }
 
 ####################################################################################################
 1;
