@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EURid EPP extensions
 ##
-## Copyright (c) 2005,2007 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -24,7 +24,7 @@ use base qw/Net::DRI::Protocol::EPP/;
 use Net::DRI::Data::Contact::EURid;
 use Net::DRI::Protocol::EPP::Extensions::EURid::Message;
 
-our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -54,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007,2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,10 +70,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my $h=shift;
- my $c=ref($h) || $h;
-
- my ($drd,$version,$extrah)=@_;
+ my ($c,$drd,$version,$extrah)=@_;
  my %e=map { $_ => 1 } (defined($extrah)? (ref($extrah)? @$extrah : ($extrah)) : ());
 
  $e{'Net::DRI::Protocol::EPP::Extensions::EURid::Domain'}=1;
@@ -81,25 +78,20 @@ sub new
  $e{'Net::DRI::Protocol::EPP::Extensions::NSgroup'}=1;
  ## Sunrise should be added when calling, as it is not mandatory
 
- my $self=$c->SUPER::new($drd,$version,[keys(%e)]); ## we are now officially a Net::DRI::Protocol::EPP object
+ my $self=$c->SUPER::new($drd,$version,[keys(%e)]);
+ $version=$self->version(); ## make sure it is correctly set
 
- $self->{ns}->{_main}=['http://www.eurid.eu/xml/epp/epp-1.0','epp-1.0.xsd'];
+ $self->ns({_main => ['http://www.eurid.eu/xml/epp/epp-1.0','epp-1.0.xsd']});
  foreach my $w ('domain','contact','eurid','nsgroup')
  {
-  $self->{ns}->{$w}=['http://www.eurid.eu/xml/epp/'.$w.'-1.0',$w.'-1.0.xsd'];
+  $self->ns({ $w => ['http://www.eurid.eu/xml/epp/'.$w.'-1.0',$w.'-1.0.xsd'] });
  }
-
- my $rcapa=$self->capabilities();
- delete($rcapa->{contact_update}->{status}); ## No changes in status possible for .EU domains/contacts
- delete($rcapa->{domain_update}->{status});
-
- my $rfact=$self->factories();
- $rfact->{contact}=sub { return Net::DRI::Data::Contact::EURid->new()->srid('ABCD') };
- $rfact->{message}=sub { my $m=Net::DRI::Protocol::EPP::Extensions::EURid::Message->new(@_); $m->ns($self->{ns}); $m->version($version); return $m;};
-
+ $self->capabilities('contact_update','status',undef); ## No changes in status possible for .EU domains/contacts
+ $self->capabilities('domain_update','status',undef);
+ $self->capabilities('domain_update','nsgroup',[ 'add','del']);
+ $self->factories('contact',sub { return Net::DRI::Data::Contact::EURid->new()->srid('ABCD') });
+ $self->factories('message',sub { my $m=Net::DRI::Protocol::EPP::Extensions::EURid::Message->new(@_); $m->ns($self->{ns}); $m->version($version); return $m;} );
  $self->default_parameters({domain_create => { auth => { pw => '' } } });
-
- bless($self,$c); ## rebless
  return $self;
 }
 
