@@ -1,7 +1,6 @@
 ## Domain Registry Interface, .PRO A/V extensions
 ##
-## Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##               2018 Patrick Mevzek <netdri@dotandco.com>
+## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -12,17 +11,21 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::EPP::Extensions::PRO::AV;
 
 use strict;
-use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
 use DateTime::Format::ISO8601;
 
+our $VERSION=do { my @r = (q$Revision: 1.1 $ =~ /\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -54,8 +57,7 @@ E<lt>http://www.hexonet.net/E<gt>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-              2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -102,7 +104,7 @@ sub build_command
 	}
 
 	my $tcommand = (ref($command) ? $command->[0] : $command);
-	$msg->command([$command, 'av:' . $tcommand, $msg->nsattrs('av')]);
+	$msg->command([$command, 'av:' . $tcommand,sprintf('xmlns:av="%s" xsi:schemaLocation="%s %s"',$msg->nsattrs('av'))]);
 	return map { ['av:id', $_, $domainattr] } @dom;
 }
 
@@ -112,7 +114,6 @@ sub check
 	my $mes = $epp->message();
 	my @d = build_command($mes, 'check', $av);
 	$mes->command_body(\@d);
-	return;
 }
 
 sub check_parse
@@ -157,7 +158,6 @@ sub check_parse
 			}
 		} continue { $c = $c->getNextSibling(); }
 	} continue { $cd = $cd->getNextSibling(); }
-	return;
 }
 
 sub info
@@ -166,7 +166,6 @@ sub info
 	my $mes = $epp->message();
 	my @d = build_command($mes, 'info', $av);
 	$mes->command_body(\@d);
-	return;
 }
 
 sub info_parse
@@ -222,7 +221,7 @@ sub info_parse
 		}
 		elsif (lc($cdn) eq 'contactid')
 		{
-			my $c = $po->create_local_object('contact');
+			my $c = $po->factories()->{contact}->();
 			$c->srid($cd->getFirstChild()->getData());
 			$rinfo->{av}->{$avid}->{contact} = $c;
 		}
@@ -275,7 +274,7 @@ sub info_parse
 			$rinfo->{av}->{$avid}->{avresult} = $res;
 		}
 	} continue { $cd = $cd->getNextSibling(); }
-	return;
+
 }
 
 ####################################################################################################
@@ -292,7 +291,6 @@ sub create
 	push(@d, ['av:contact', ['av:contactId', $rd->{contact}->srid()]]) if (Net::DRI::Util::has_key($rd,'contact') && Net::DRI::Util::isa_contact($rd->{contact}));
 
 	$mes->command_body(\@d);
-	return;
 }
 
 sub create_parse
@@ -331,7 +329,6 @@ sub create_parse
 				$cd->getFirstChild()->getData());
 		}
 	} continue { $cd = $cd->getNextSibling(); }
-	return;
 }
 
 ####################################################################################################
