@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OpenSRS XCP Protocol
 ##
-## Copyright (c) 2008-2010,2012,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,17 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 ####################################################################################################
 
 package Net::DRI::Protocol::OpenSRS::XCP;
 
 use strict;
-use warnings;
 
 use base qw(Net::DRI::Protocol);
 
 use Net::DRI::Protocol::OpenSRS::XCP::Message;
-use Net::DRI::Data::Contact::OpenSRS;
+
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -50,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2012,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,31 +69,21 @@ See the LICENSE file that comes with this distribution for more details.
 
 sub new
 {
- my ($c,$ctx,$rp)=@_;
- my $drd=$ctx->{registry}->driver();
- my $self=$c->SUPER::new($ctx);
+ my ($c,$drd)=@_;
+
+ my $self=$c->SUPER::new();
  $self->name('opensrs_xcp');
  $self->version('3.0'); ## Specification March 17, 2008
  $self->factories('message',sub { my $m=Net::DRI::Protocol::OpenSRS::XCP::Message->new(); return $m; });
-## $self->factories('message',sub { my $m=Net::DRI::Protocol::OpenSRS::XCP::Message->new(@_); $m->client_auth({id => $drd->{client_login}, pw => $drd->{client_password}}); return $m; });
- $self->factories('contact',sub { return Net::DRI::Data::Contact::OpenSRS->new(); });
- $self->capabilities('domain_update', 'ns', [ 'set' ]);
- $self->capabilities('domain_update', 'contact', [ 'set' ]);
- $self->_load($rp);
+ $self->_load();
  return $self;
 }
 
 sub _load
 {
- my ($self,$rp)=@_;
- my @class=map { 'Net::DRI::Protocol::OpenSRS::XCP::'.$_ } (qw/Account Domain Host Session/);
- return $self->SUPER::_load(@class);
-}
-
-sub transport_default
-{
- my ($self)=@_;
- return (protocol_connection => 'Net::DRI::Protocol::OpenSRS::XCP::Connection', protocol_version => '3.0');
+ my ($self,$extrah)=@_;
+ my @class=map { 'Net::DRI::Protocol::OpenSRS::XCP::'.$_ } (qw/Account Domain Session/);
+ $self->SUPER::_load(@class);
 }
 
 ####################################################################################################
