@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OpenSRS XCP Account commands
 ##
-## Copyright (c) 2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -10,16 +10,20 @@
 ## (at your option) any later version.
 ##
 ## See the LICENSE file that comes with this distribution for more details.
+#
+# 
+#
 #########################################################################################
 
 package Net::DRI::Protocol::OpenSRS::XCP::Account;
 
 use strict;
-use warnings;
 
 use Net::DRI::Exception;
 use DateTime;
 
+our $VERSION=do { my @r=(q$Revision: 1.1 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+
 =pod
 
 =head1 NAME
@@ -48,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -78,7 +82,6 @@ sub list_domains
  my $msg=$xcp->message();
  $msg->command({action=>'get_domains_by_expiredate',object=>'domain'});
  $msg->command_attributes({exp_from=>DateTime->from_epoch(epoch => time()-60*60*24)->strftime('%F'),exp_to=>'2030-01-01',limit=>1000000}); ## We have to provide a limit !
- return;
 }
 
 sub list_domains_parse
@@ -93,7 +96,6 @@ sub list_domains_parse
  my @r=map { $_->{name} } @$rd;
  $rinfo->{account}->{domains}->{action}='list';
  $rinfo->{account}->{domains}->{list}=\@r;
- return;
 }
 
 ####################################################################################################
